@@ -1,20 +1,22 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd2.2.6"
+#define HOST_OS "freebsd2.2.7"
 #define HOST_OS_NAME "freebsd2"
-#define HOST_OS_VERSION "2.2.6"
+#define HOST_OS_VERSION "2.2.7"
 #define HOST_ARCH "i386"
-#define HOST_NAME "dingo.mcl.cs.columbia.edu"
+#define HOST_NAME "bmt.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Fri Jul 17 06:48:48 EDT 1998"
+#define CONFIG_DATE "Tue Jul  4 17:50:22 EDT 2000"
 #define PACKAGE "am-utils"
-#define VERSION "6.0a17s2"
+#define VERSION "6.0.4s6"
 #define PACKAGE "am-utils"
-#define VERSION "6.0a17s2"
+#define VERSION "6.0.4s6"
 #define DEBUG 1
+#define HOST_HEADER_VERSION "2.2.7"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
+#define HAVE_ALLOCA 1
 #define STDC_HEADERS 1
 #define HAVE_WAIT3 1
 #define HAVE__SETERR_REPLY 1
@@ -44,6 +46,7 @@
 #define HAVE_RMDIR 1
 #define HAVE_SELECT 1
 #define HAVE_SETEUID 1
+#define HAVE_SETITIMER 1
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
@@ -61,6 +64,7 @@
 #define HAVE_UNAME 1
 #define HAVE_UNMOUNT 1
 #define HAVE_VFORK 1
+#define HAVE_VSNPRINTF 1
 #define HAVE_WAIT3 1
 #define HAVE_WAITPID 1
 #define HAVE_CLNT_SPERRNO 1
@@ -119,10 +123,10 @@
 #define HAVE_NETINET_IF_ETHER_H 1
 #define HAVE_NETINET_IN_H 1
 #define HAVE_NFS_NFS_H 1
+#define HAVE_NFS_NFSMOUNT_H 1
 #define HAVE_NFS_NFSPROTO_H 1
 #define HAVE_NFS_NFSV2_H 1
 #define HAVE_NFS_RPCV2_H 1
-#define HAVE_NFS_RPCV2_H 1
 #define HAVE_RPC_PMAP_CLNT_H 1
 #define HAVE_RPC_PMAP_PROT_H 1
 #define HAVE_RPC_RPC_H 1
@@ -154,6 +158,7 @@
 #define HAVE_SYS_UIO_H 1
 #define HAVE_SYS_UTSNAME_H 1
 #define HAVE_SYS_VNODE_H 1
+#define HAVE_UFS_UFS_UFSMOUNT_H 1
 #define HAVE_ASSERT_H 1
 #define HAVE_CTYPE_H 1
 #define HAVE_ERRNO_H 1
@@ -177,7 +182,6 @@
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
 #define TIME_WITH_SYS_TIME 1
-#define HAVE_ST_RDEV 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_freebsd2.h"
 #define HAVE_STRUCT_NFS_ARGS 1
 #define nfs_args_t struct nfs_args
@@ -200,6 +204,7 @@
 #define voidp void *
 #define HAVE_EXTERN_SYS_ERRLIST 1
 #define HAVE_EXTERN_OPTARG 1
+#define HAVE_EXTERN_CLNT_SPCREATEERROR 1
 #define HAVE_EXTERN_CLNT_SPERRNO 1
 #define HAVE_EXTERN_FREE 1
 #define HAVE_EXTERN_GETDOMAINNAME 1
@@ -210,12 +215,15 @@
 #define HAVE_EXTERN_GETWD 1
 #define HAVE_EXTERN_MKSTEMP 1
 #define HAVE_EXTERN_SBRK 1
+#define HAVE_EXTERN_SETEUID 1
+#define HAVE_EXTERN_SETITIMER 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
 #define HAVE_EXTERN_USLEEP 1
 #define HAVE_EXTERN_WAIT3 1
+#define HAVE_EXTERN_VSNPRINTF 1
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
 #define HAVE_FIELD_CDFS_ARGS_T_FLAGS 1
@@ -231,15 +239,10 @@
 #define HAVE_FIELD_NFS_ARGS_T_SOTYPE 1
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
-#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
-#define HAVE_DBM_OPEN 1
 #define HAVE_MAP_NDBM 1
-#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
-#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
-#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_LOFS 1
@@ -251,18 +254,18 @@
 #define HAVE_FS_NULLFS 1
 #define HAVE_FS_UNIONFS 1
 #define HAVE_FS_UMAPFS 1
-#define HAVE_AM_FS_AUTO 1
-#define HAVE_AM_FS_DIRECT 1
-#define HAVE_AM_FS_TOPLVL 1
-#define HAVE_AM_FS_ERROR 1
-#define HAVE_AM_FS_INHERIT 1
-#define HAVE_AM_FS_PROGRAM 1
-#define HAVE_AM_FS_LINK 1
-#define HAVE_AM_FS_LINKX 1
-#define HAVE_AM_FS_HOST 1
-#define HAVE_AM_FS_NFSX 1
-#define HAVE_AM_FS_NFSL 1
-#define HAVE_AM_FS_UNION 1
+#define HAVE_AMU_FS_AUTO 1
+#define HAVE_AMU_FS_DIRECT 1
+#define HAVE_AMU_FS_TOPLVL 1
+#define HAVE_AMU_FS_ERROR 1
+#define HAVE_AMU_FS_INHERIT 1
+#define HAVE_AMU_FS_PROGRAM 1
+#define HAVE_AMU_FS_LINK 1
+#define HAVE_AMU_FS_LINKX 1
+#define HAVE_AMU_FS_HOST 1
+#define HAVE_AMU_FS_NFSX 1
+#define HAVE_AMU_FS_NFSL 1
+#define HAVE_AMU_FS_UNION 1
 #define MOUNT_TYPE_NFS MOUNT_NFS
 #define MOUNT_TYPE_UFS MOUNT_UFS
 #define MOUNT_TYPE_CDFS MOUNT_CD9660
@@ -287,21 +290,29 @@
 #define MNTTAB_TYPE_NULLFS "null"
 #define MNTTAB_TYPE_UNIONFS "union"
 #define MNTTAB_TYPE_UMAPFS "umap"
+#define MNT2_GEN_OPT_ASYNC 0x40
 #define MNT2_GEN_OPT_NODEV 0x10
 #define MNT2_GEN_OPT_NOEXEC 0x4
 #define MNT2_GEN_OPT_NOSUID 0x8
 #define MNT2_GEN_OPT_QUOTA 0x2000
 #define MNT2_GEN_OPT_RDONLY 0x1
+#define MNT2_GEN_OPT_SYNCHRONOUS 0x2
+#define MNT2_NFS_OPT_DEADTHRESH 0x4000
 #define MNT2_NFS_OPT_DUMBTIMR 0x800
 #define MNT2_NFS_OPT_INT 0x40
+#define MNT2_NFS_OPT_LEASETERM 0x1000
 #define MNT2_NFS_OPT_MAXGRPS 0x20
 #define MNT2_NFS_OPT_NFSV3 0x200
 #define MNT2_NFS_OPT_NOCONN 0x80
+#define MNT2_NFS_OPT_NQNFS 0x100
+#define MNT2_NFS_OPT_READAHEAD 0x2000
 #define MNT2_NFS_OPT_RESVPORT 0x8000
 #define MNT2_NFS_OPT_RETRANS 0x10
 #define MNT2_NFS_OPT_RSIZE 0x4
 #define MNT2_NFS_OPT_SOFT 0x1
 #define MNT2_NFS_OPT_TIMEO 0x8
 #define MNT2_NFS_OPT_WSIZE 0x2
+#define MNT2_CDFS_OPT_EXTATT 0x4
+#define MNT2_CDFS_OPT_GENS 0x2
+#define MNT2_CDFS_OPT_NORRIP 0x1
 #define HIDE_MOUNT_TYPE "nfs"
-#define HAVE_GETMNTINFO 1
